==> mall-center-api-0.0.4-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActConfDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import cn.com.duiba.mall.center.api.domain.enums.seckill.SecKillActConfEnableStatusEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/14 13:58.
 */
public class SecKillActConfDto implements Serializable {
    private static final long serialVersionUID = 7907836921723003123L;

    /**
     * 活动id
     */
    private Long id;

    /**
     * 对应的应用id
     */
    private Long appId;

    /**
     * 启用状态
     */
    private SecKillActConfEnableStatusEnum enableStatusEnum;

    /**
     * 活动名称
     */
    private String title;

    /**
     * 单人限购上限
     */
    private Integer perLimit;

    /**
     * 开始时间
     */
    private Date gmtStart;

    /**
     * 结束时间
     */
    private Date gmtEnd;

    /**
     * 对应的商品id
     */
    private Long appItemId;

    /**
     * 对应的商品类型
     */
    private String itemType;

    /**
     * 对应的商品标题
     */
    private String itemTitle;

    /**
     * 对应的商品小图链接
     */
    private String itemSmallImage;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public SecKillActConfEnableStatusEnum getEnableStatusEnum() {
        return enableStatusEnum;
    }

    public void setEnableStatusEnum(SecKillActConfEnableStatusEnum enableStatusEnum) {
        this.enableStatusEnum = enableStatusEnum;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPerLimit() {
        return perLimit;
    }

    public void setPerLimit(Integer perLimit) {
        this.perLimit = perLimit;
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtEnd() {
        return gmtEnd;
    }

    public void setGmtEnd(Date gmtEnd) {
        this.gmtEnd = gmtEnd;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getItemTitle() {
        return itemTitle;
    }

    public void setItemTitle(String itemTitle) {
        this.itemTitle = itemTitle;
    }

    public String getItemSmallImage() {
        return itemSmallImage;
    }

    public void setItemSmallImage(String itemSmallImage) {
        this.itemSmallImage = itemSmallImage;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> mall-center-api-0.1.12-p1-20211124.094319-2-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActConfDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import cn.com.duiba.mall.center.api.domain.enums.seckill.SecKillActConfEnableStatusEnum;
import cn.com.duiba.mall.center.api.domain.enums.seckill.SecKillActConfModeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/14 13:58.
 */
public class SecKillActConfDto implements Serializable {
    private static final long serialVersionUID = 7907836921723003123L;

    /**
     * 活动id
     */
    private Long id;

    /**
     * 对应的应用id
     */
    private Long appId;

    /**
     * 启用状态
     */
    private SecKillActConfEnableStatusEnum enableStatusEnum;

    /**
     * 活动名称
     */
    private String title;

    /**
     * 单人限购上限
     */
    private Integer perLimit;

    /**
     * 开始时间
     */
    private Date gmtStart;

    /**
     * 结束时间
     */
    private Date gmtEnd;

    /**
     * 模式
     */
    private SecKillActConfModeEnum modeEnum;

    /**
     * 对应的商品id
     */
    private Long appItemId;

    /**
     * 对应的商品类型
     */
    private String itemType;

    /**
     * 对应的商品标题
     */
    private String itemTitle;

    /**
     * 对应的商品小图链接
     */
    private String itemSmallImage;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public SecKillActConfEnableStatusEnum getEnableStatusEnum() {
        return enableStatusEnum;
    }

    public void setEnableStatusEnum(SecKillActConfEnableStatusEnum enableStatusEnum) {
        this.enableStatusEnum = enableStatusEnum;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPerLimit() {
        return perLimit;
    }

    public void setPerLimit(Integer perLimit) {
        this.perLimit = perLimit;
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtEnd() {
        return gmtEnd;
    }

    public void setGmtEnd(Date gmtEnd) {
        this.gmtEnd = gmtEnd;
    }

    public SecKillActConfModeEnum getModeEnum() {
        return modeEnum;
    }

    public void setModeEnum(SecKillActConfModeEnum modeEnum) {
        this.modeEnum = modeEnum;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getItemTitle() {
        return itemTitle;
    }

    public void setItemTitle(String itemTitle) {
        this.itemTitle = itemTitle;
    }

    public String getItemSmallImage() {
        return itemSmallImage;
    }

    public void setItemSmallImage(String itemSmallImage) {
        this.itemSmallImage = itemSmallImage;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
